


<div class="row"><div class="col-md-12"><div class="kachelRund"><table class="table table-striped"><tr><th>Fläche</th><th>Bezeichnung</th><th>Zähler-Nr.</th><th>Zeitpunkt</th><th class="alignright">Zählerstand</th><th>Einheit</th></tr><tr><td>H12W34</td><td>Verbrauch Kaltwasser H12W34 Bad</td><td>00000001</td><td></td><td class="alignright">1.234,56</td><td></td></tr><tr><td>H12W34</td><td>Verbrauch Kaltwasser H12W34 WC</td><td>00000002</td><td></td><td class="alignright">1.234,56</td><td></td></tr><tr><td>H12W34</td><td>Verbrauch Strom H12W34</td><td>00000003</td><td></td><td class="alignright">1.234,56</td><td></td></tr><tr><td>H12W34</td><td>Verbrauch Wärme H12W34</td><td>00000004</td><td></td><td class="alignright">1.234,56</td><td></td></tr><tr><td>H12W34</td><td>Verbrauch Warmwasser H12W34 Bad</td><td>00000005</td><td></td><td class="alignright">1.234,56</td><td></td></tr><tr><td>H12W34</td><td>Verbrauch Warmwasser H12W34 WC</td><td>00000006</td><td></td><td class="alignright">1.234,56</td><td></td></tr></table></div></div></div>