<!DOCTYPE html>
<html lang="de">
  <head>
      <meta charset="utf-8">
      <meta http-equiv="X-UA-Compatible" content="IE=edge">
      <meta name="viewport" content="width=device-width, initial-scale=1.0">
      <meta name="description" content="enocoo | Abgemeldet">
      <meta name="author" content="enocoo">
    <!--link rel="shortcut icon" href="../images/favicon.ico"-->
	<link rel="apple-touch-icon" sizes="180x180" href="../apple-touch-icon.png">
	<link rel="icon" type="image/png" sizes="32x32" href="../favicon-32x32.png">
	<link rel="icon" type="image/png" sizes="16x16" href="../favicon-16x16.png">
	<link rel="manifest" href="../site.webmanifest.json">
	<link rel="mask-icon" href="../safari-pinned-tab.svg" color="#5bbad5">
	<meta name="msapplication-TileColor" content="#2d89ef">
	<meta name="theme-color" content="#ffffff">

      <title>enocoo | Abgemeldet</title>
      <link href="../css/signInStyle.css" rel="stylesheet">
  </head>
  <body>
    <p /><DIV ALIGN=CENTER class="loggedOut"><a id="logo"><img align="center" src="../images/ENOCOO_LOGO_300x111.png" alt="enocoo Logo" /></a><h3>Sie sind nicht angemeldet.</h3><strong>M&ouml;glicherweise ist Ihre Sitzung abgelaufen.<br />Bitte gehen Sie zur <a href="../signinForm.php">Anmelde-Seite</a><br />und melden Sie sich an.</strong></DIV>  </body>
</html>
